@@ -12,7 +12,7 @@ Usage::
     client: ManagedBlockchainClient = boto3.client("managedblockchain")
     ```
 """
-from typing import Any, Dict, List, Type
+from typing import Any, Dict, Mapping, Sequence, Type
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -54,7 +54,7 @@ __all__ = ("ManagedBlockchainClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -75,7 +75,7 @@ class Exceptions:
 
 class ManagedBlockchainClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html)
     """
 
@@ -91,7 +91,7 @@ class ManagedBlockchainClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#can_paginate)
         """
 
@@ -106,7 +106,7 @@ class ManagedBlockchainClient(BaseClient):
         """
         Creates a member within a Managed Blockchain network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.create_member)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.create_member)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#create_member)
         """
 
@@ -119,14 +119,14 @@ class ManagedBlockchainClient(BaseClient):
         FrameworkVersion: str,
         VotingPolicy: "VotingPolicyTypeDef",
         MemberConfiguration: "MemberConfigurationTypeDef",
-        Description: str = None,
-        FrameworkConfiguration: "NetworkFrameworkConfigurationTypeDef" = None,
-        Tags: Dict[str, str] = None
+        Description: str = ...,
+        FrameworkConfiguration: "NetworkFrameworkConfigurationTypeDef" = ...,
+        Tags: Mapping[str, str] = ...
     ) -> CreateNetworkOutputTypeDef:
         """
         Creates a new blockchain network using Amazon Managed Blockchain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.create_network)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.create_network)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#create_network)
         """
 
@@ -136,13 +136,13 @@ class ManagedBlockchainClient(BaseClient):
         ClientRequestToken: str,
         NetworkId: str,
         NodeConfiguration: "NodeConfigurationTypeDef",
-        MemberId: str = None,
-        Tags: Dict[str, str] = None
+        MemberId: str = ...,
+        Tags: Mapping[str, str] = ...
     ) -> CreateNodeOutputTypeDef:
         """
         Creates a node on the specified blockchain network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.create_node)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.create_node)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#create_node)
         """
 
@@ -153,14 +153,14 @@ class ManagedBlockchainClient(BaseClient):
         NetworkId: str,
         MemberId: str,
         Actions: "ProposalActionsTypeDef",
-        Description: str = None,
-        Tags: Dict[str, str] = None
+        Description: str = ...,
+        Tags: Mapping[str, str] = ...
     ) -> CreateProposalOutputTypeDef:
         """
         Creates a proposal for a change to the network that other members of the network
         can vote on, for example, a proposal to add a new member to the network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.create_proposal)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.create_proposal)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#create_proposal)
         """
 
@@ -168,29 +168,29 @@ class ManagedBlockchainClient(BaseClient):
         """
         Deletes a member.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.delete_member)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.delete_member)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#delete_member)
         """
 
-    def delete_node(self, *, NetworkId: str, NodeId: str, MemberId: str = None) -> Dict[str, Any]:
+    def delete_node(self, *, NetworkId: str, NodeId: str, MemberId: str = ...) -> Dict[str, Any]:
         """
         Deletes a node that your AWS account owns.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.delete_node)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.delete_node)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#delete_node)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#generate_presigned_url)
         """
 
@@ -198,7 +198,7 @@ class ManagedBlockchainClient(BaseClient):
         """
         Returns detailed information about a member.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.get_member)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.get_member)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#get_member)
         """
 
@@ -206,17 +206,15 @@ class ManagedBlockchainClient(BaseClient):
         """
         Returns detailed information about a network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.get_network)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.get_network)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#get_network)
         """
 
-    def get_node(
-        self, *, NetworkId: str, NodeId: str, MemberId: str = None
-    ) -> GetNodeOutputTypeDef:
+    def get_node(self, *, NetworkId: str, NodeId: str, MemberId: str = ...) -> GetNodeOutputTypeDef:
         """
         Returns detailed information about a node.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.get_node)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.get_node)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#get_node)
         """
 
@@ -224,17 +222,17 @@ class ManagedBlockchainClient(BaseClient):
         """
         Returns detailed information about a proposal.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.get_proposal)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.get_proposal)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#get_proposal)
         """
 
     def list_invitations(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListInvitationsOutputTypeDef:
         """
         Returns a list of all invitations for the current AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_invitations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_invitations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#list_invitations)
         """
 
@@ -242,34 +240,34 @@ class ManagedBlockchainClient(BaseClient):
         self,
         *,
         NetworkId: str,
-        Name: str = None,
-        Status: MemberStatusType = None,
-        IsOwned: bool = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        Name: str = ...,
+        Status: MemberStatusType = ...,
+        IsOwned: bool = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> ListMembersOutputTypeDef:
         """
         Returns a list of the members in a network and properties of their
         configurations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_members)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_members)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#list_members)
         """
 
     def list_networks(
         self,
         *,
-        Name: str = None,
-        Framework: FrameworkType = None,
-        Status: NetworkStatusType = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        Name: str = ...,
+        Framework: FrameworkType = ...,
+        Status: NetworkStatusType = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> ListNetworksOutputTypeDef:
         """
         Returns information about the networks in which the current AWS account
         participates.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_networks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_networks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#list_networks)
         """
 
@@ -277,36 +275,36 @@ class ManagedBlockchainClient(BaseClient):
         self,
         *,
         NetworkId: str,
-        MemberId: str = None,
-        Status: NodeStatusType = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        MemberId: str = ...,
+        Status: NodeStatusType = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> ListNodesOutputTypeDef:
         """
         Returns information about the nodes within a network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_nodes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_nodes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#list_nodes)
         """
 
     def list_proposal_votes(
-        self, *, NetworkId: str, ProposalId: str, MaxResults: int = None, NextToken: str = None
+        self, *, NetworkId: str, ProposalId: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListProposalVotesOutputTypeDef:
         """
         Returns the list of votes for a specified proposal, including the value of each
         vote and the unique identifier of the member that cast the vote.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_proposal_votes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_proposal_votes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#list_proposal_votes)
         """
 
     def list_proposals(
-        self, *, NetworkId: str, MaxResults: int = None, NextToken: str = None
+        self, *, NetworkId: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListProposalsOutputTypeDef:
         """
         Returns a list of proposals for the network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_proposals)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_proposals)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#list_proposals)
         """
 
@@ -314,7 +312,7 @@ class ManagedBlockchainClient(BaseClient):
         """
         Returns a list of tags for the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#list_tags_for_resource)
         """
 
@@ -322,24 +320,24 @@ class ManagedBlockchainClient(BaseClient):
         """
         Rejects an invitation to join a network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.reject_invitation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.reject_invitation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#reject_invitation)
         """
 
-    def tag_resource(self, *, ResourceArn: str, Tags: Dict[str, str]) -> Dict[str, Any]:
+    def tag_resource(self, *, ResourceArn: str, Tags: Mapping[str, str]) -> Dict[str, Any]:
         """
         Adds or overwrites the specified tags for the specified Amazon Managed
         Blockchain resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, ResourceArn: str, TagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Removes the specified tags from the Amazon Managed Blockchain resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#untag_resource)
         """
 
@@ -348,12 +346,12 @@ class ManagedBlockchainClient(BaseClient):
         *,
         NetworkId: str,
         MemberId: str,
-        LogPublishingConfiguration: "MemberLogPublishingConfigurationTypeDef" = None
+        LogPublishingConfiguration: "MemberLogPublishingConfigurationTypeDef" = ...
     ) -> Dict[str, Any]:
         """
         Updates a member configuration with new parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.update_member)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.update_member)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#update_member)
         """
 
@@ -362,13 +360,13 @@ class ManagedBlockchainClient(BaseClient):
         *,
         NetworkId: str,
         NodeId: str,
-        MemberId: str = None,
-        LogPublishingConfiguration: "NodeLogPublishingConfigurationTypeDef" = None
+        MemberId: str = ...,
+        LogPublishingConfiguration: "NodeLogPublishingConfigurationTypeDef" = ...
     ) -> Dict[str, Any]:
         """
         Updates a node configuration with new parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.update_node)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.update_node)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#update_node)
         """
 
@@ -378,6 +376,6 @@ class ManagedBlockchainClient(BaseClient):
         """
         Casts a vote for a specified `ProposalId` on behalf of a member.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.vote_on_proposal)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/managedblockchain.html#ManagedBlockchain.Client.vote_on_proposal)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#vote_on_proposal)
         """
